//****************************************************************************
// @Module        Ports
// @Filename      IO.H
// @Project       ser_comm
//----------------------------------------------------------------------------
// @Controller    Siemens C164CI-8E
//
// @Compiler      Tasking C166 V5.0
//
// @Codegenerator DAvE 1-1-1
//
// @Description   This file contains all function prototypes and macros for
//                the Parallel Ports.
//
//----------------------------------------------------------------------------
// @Date          14.06.2000 23:02:07
//
//****************************************************************************

//****************************************************************************
// @Prototypes of global functions
//****************************************************************************

void IO_vInit(void);


// USER CODE BEGIN (IOHeader,1)

// USER CODE END


//****************************************************************************
// @Macros
//****************************************************************************

//****************************************************************************
// @Macro          IO_bReadPin(PinNr)
//
//----------------------------------------------------------------------------
// @Description   This macro returns the status of the chosen portpin.
//                Warning:
//                All instructions that manipulate single bits or bit
//                groups internally, use a read-modify-write sequence
//                that accesses the whole word, which contains the
//                specified bit(s).
//                The read modify-write approach may be critical with
//                hardware-effected bits. In this cases the hardware
//                may change specific bits while the read-modify-write
//                operation is in progress, where the writeback would
//                overwrite the new bit value generated by the hardware.
//                The solution is either the implemented hardware 
//                protection or realized through special programming
//                (see "Particular Pipeline Effects" and "Protected
//                Bits" in the User's Manual). 
//                
//                Note:
//                See the "Declaration of bit addressable SFRs" 
//                section in the header file for the available 
//                definitions for the parameter PinNr.
//
//----------------------------------------------------------------------------
// @Returnvalue   status of the chosen portpin
//
//----------------------------------------------------------------------------
// @Parameters    pin to be read
//
//----------------------------------------------------------------------------
// @Date          14.06.2000 23:02:07
//
//****************************************************************************

#define IO_bReadPin(PinNr) PinNr


//****************************************************************************
// @Macro          IO_vSetPin(PinNr)
//
//----------------------------------------------------------------------------
// @Description   The chosen portpin is set to '1'.
//                Warning:
//                All instructions that manipulate single bits or bit
//                groups internally, use a read-modify-write sequence
//                that accesses the whole word, which contains the
//                specified bit(s).
//                The read modify-write approach may be critical with
//                hardware-effected bits. In this cases the hardware
//                may change specific bits while the read-modify-write
//                operation is in progress, where the writeback would
//                overwrite the new bit value generated by the hardware.
//                The solution is either the implemented hardware 
//                protection or realized through special programming
//                (see "Particular Pipeline Effects" and "Protected
//                Bits" in the User's Manual). 
//                
//                Note:
//                See the "Declaration of bit addressable SFRs" 
//                section in the header file for the available 
//                definitions for the parameter PinNr.
//
//----------------------------------------------------------------------------
// @Returnvalue   none
//
//----------------------------------------------------------------------------
// @Parameters    pin to be set to '1'
//
//----------------------------------------------------------------------------
// @Date          14.06.2000 23:02:07
//
//****************************************************************************

#define IO_vSetPin(PinNr) PinNr = 1


//****************************************************************************
// @Macro          IO_vResetPin(PinNr)
//
//----------------------------------------------------------------------------
// @Description   The chosen portpin is set to '0'.
//                Warning:
//                All instructions that manipulate single bits or bit
//                groups internally, use a read-modify-write sequence
//                that accesses the whole word, which contains the
//                specified bit(s).
//                The read modify-write approach may be critical with
//                hardware-effected bits. In this cases the hardware
//                may change specific bits while the read-modify-write
//                operation is in progress, where the writeback would
//                overwrite the new bit value generated by the hardware.
//                The solution is either the implemented hardware 
//                protection or realized through special programming
//                (see "Particular Pipeline Effects" and "Protected
//                Bits" in the User's Manual). 
//                
//                Note:
//                See the "Declaration of bit addressable SFRs" 
//                section in the header file for the available 
//                definitions for the parameter PinNr.
//
//----------------------------------------------------------------------------
// @Returnvalue   none
//
//----------------------------------------------------------------------------
// @Parameters    pin to be set to '0'
//
//----------------------------------------------------------------------------
// @Date          14.06.2000 23:02:07
//
//****************************************************************************

#define IO_vResetPin(PinNr) PinNr = 0


//****************************************************************************
// @Macro          IO_uwReadPort(PortNr)
//
//----------------------------------------------------------------------------
// @Description   This macro returns the value of the selected port. If a 
//                port has less than 16 pins, the unused bits are
//                set to 0 in the return value
//                
//                The following definitions for PortNr are available:
//                P0L,P0H,P1L,P1H,P3,P4,P5,P8
//
//----------------------------------------------------------------------------
// @Returnvalue   value of the port
//
//----------------------------------------------------------------------------
// @Parameters    port to be read
//
//----------------------------------------------------------------------------
// @Date          14.06.2000 23:02:07
//
//****************************************************************************

#define IO_uwReadPort(Port) Port



// USER CODE BEGIN (IOHeader,2)

// USER CODE END


//****************************************************************************
// Declaration of bit addressable SFRs (for parameter PinNr)
//****************************************************************************

sfrbit  P0L_0 _atbit(P0L, 0);
sfrbit  P0L_1 _atbit(P0L, 1);
sfrbit  P0L_2 _atbit(P0L, 2);
sfrbit  P0L_3 _atbit(P0L, 3);
sfrbit  P0L_4 _atbit(P0L, 4);
sfrbit  P0L_5 _atbit(P0L, 5);
sfrbit  P0L_6 _atbit(P0L, 6);
sfrbit  P0L_7 _atbit(P0L, 7);
sfrbit  P0H_0 _atbit(P0H, 0);
sfrbit  P0H_1 _atbit(P0H, 1);
sfrbit  P0H_2 _atbit(P0H, 2);
sfrbit  P0H_3 _atbit(P0H, 3);
sfrbit  P0H_4 _atbit(P0H, 4);
sfrbit  P0H_5 _atbit(P0H, 5);
sfrbit  P0H_6 _atbit(P0H, 6);
sfrbit  P0H_7 _atbit(P0H, 7);
sfrbit  P1L_0 _atbit(P1L, 0);
sfrbit  P1L_1 _atbit(P1L, 1);
sfrbit  P1L_2 _atbit(P1L, 2);
sfrbit  P1L_3 _atbit(P1L, 3);
sfrbit  P1L_4 _atbit(P1L, 4);
sfrbit  P1L_5 _atbit(P1L, 5);
sfrbit  P1L_6 _atbit(P1L, 6);
sfrbit  P1L_7 _atbit(P1L, 7);
sfrbit  P1H_0 _atbit(P1H, 0);
sfrbit  P1H_1 _atbit(P1H, 1);
sfrbit  P1H_2 _atbit(P1H, 2);
sfrbit  P1H_3 _atbit(P1H, 3);
sfrbit  P1H_4 _atbit(P1H, 4);
sfrbit  P1H_5 _atbit(P1H, 5);
sfrbit  P1H_6 _atbit(P1H, 6);
sfrbit  P1H_7 _atbit(P1H, 7);
sfrbit  P3_4 _atbit(P3, 4);
sfrbit  P3_6 _atbit(P3, 6);
sfrbit  P3_8 _atbit(P3, 8);
sfrbit  P3_9 _atbit(P3, 9);
sfrbit  P3_10 _atbit(P3, 10);
sfrbit  P3_11 _atbit(P3, 11);
sfrbit  P3_12 _atbit(P3, 12);
sfrbit  P3_13 _atbit(P3, 13);
sfrbit  P3_15 _atbit(P3, 15);
sfrbit  P4_0 _atbit(P4, 0);
sfrbit  P4_1 _atbit(P4, 1);
sfrbit  P4_2 _atbit(P4, 2);
sfrbit  P4_3 _atbit(P4, 3);
sfrbit  P4_5 _atbit(P4, 5);
sfrbit  P4_6 _atbit(P4, 6);
sfrbit  P5_0 _atbit(P5, 0);
sfrbit  P5_1 _atbit(P5, 1);
sfrbit  P5_2 _atbit(P5, 2);
sfrbit  P5_3 _atbit(P5, 3);
sfrbit  P5_4 _atbit(P5, 4);
sfrbit  P5_5 _atbit(P5, 5);
sfrbit  P5_6 _atbit(P5, 6);
sfrbit  P5_7 _atbit(P5, 7);
sfrbit  P8_0 _atbit(P8, 0);
sfrbit  P8_1 _atbit(P8, 1);
sfrbit  P8_2 _atbit(P8, 2);
sfrbit  P8_3 _atbit(P8, 3);


// USER CODE BEGIN (IOHeader,3)

// USER CODE END

